@@ -6,7 +6,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2017-2024 Univention GmbH
+# Copyright 2017-2025 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -258,8 +258,8 @@ class PatchRepresentationSanitizer(PatchDocumentSanitizer):
 class DictSanitizer(UMCDictSanitizer):
 
     def __init__(self, sanitizers, allow_other_keys=True, **kwargs):
-        self.default_sanitizer = kwargs.get('default_sanitizer', None)
-        self.key_sanitizer = kwargs.get('key_sanitizer', None)
+        self.default_sanitizer = kwargs.get('default_sanitizer')
+        self.key_sanitizer = kwargs.get('key_sanitizer')
         super().__init__(sanitizers, allow_other_keys=allow_other_keys, **kwargs)
 
     def _sanitize(self, value, name, further_arguments):
